@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Type::Node;
 # ABSTRACT: Describes a node from a Neo4j graph
-$Neo4j::Driver::Type::Node::VERSION = '0.40';
+$Neo4j::Driver::Type::Node::VERSION = '0.41';
 
 use parent 'Neo4j::Types::Node';
 use overload '%{}' => \&_hash, fallback => 1;
@@ -41,6 +41,7 @@ sub element_id {
 	my ($self) = @_;
 	
 	return $$self->{_meta}->{element_id} if defined $$self->{_meta}->{element_id};
+	warnings::warnif 'Neo4j::Types', 'element_id unavailable';
 	return $$self->{_meta}->{id};
 }
 
@@ -90,6 +91,13 @@ sub _private {
 }
 
 
+# As long as we remain compatible with Neo4j::Types 1.00,
+# we need to register the warning category explicitly.
+package # private
+        Neo4j::Types;
+use warnings::register;
+
+
 1;
 
 __END__
@@ -104,7 +112,7 @@ Neo4j::Driver::Type::Node - Describes a node from a Neo4j graph
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -132,6 +140,9 @@ L<Neo4j::Driver::Type::Node> objects in Perl describe the
 same node in the Neo4j database, you need to compare their
 element IDs.
 
+I<B<Note:> This module documentation will soon be replaced entirely
+by L<Neo4j::Driver::Types> and L<Neo4j::Types::Node>.>
+
 =head1 METHODS
 
 L<Neo4j::Driver::Type::Node> inherits all methods from
@@ -147,17 +158,11 @@ a particular context, for example the current transaction.
 This method provides the new element ID string introduced by
 S<Neo4j 5>. If the element ID is unavailable, for example with
 older Neo4j versions or with a L<Neo4j::Bolt> version that
-hasn't yet been updated for S<Neo4j 5>, this method provides
+hasn't yet been updated for S<Neo4j 5>, this method 
+issues a warning in the C<Neo4j::Types> category and provides
 the legacy numeric ID instead. Note that a numeric ID cannot
 successfully be used with C<elementId()> in Cypher expressions.
 
-The behaviour of this method when the element ID is unavailable
-is subject to change in a future version of the driver.
-In particular, making this a fatal error is being considered.
-This would help users to discover such issues early. See
-L<Neo4j-Types PR#3|https://github.com/johannessen/neo4j-types/pull/3>
-for further details.
-
 Neo4j element IDs are not designed to be persistent. As such,
 if you want a public identity to use for your nodes,
 attaching an explicit 'id' property is a better choice.
@@ -232,7 +237,7 @@ is returned instead.
 
 =over
 
-=item * L<Neo4j::Driver>
+=item * L<Neo4j::Driver::Types>
 
 =item * L<Neo4j::Types::Node>
 
