@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Type::Point;
 # ABSTRACT: Represents a Neo4j spatial point value
-$Neo4j::Driver::Type::Point::VERSION = '0.40';
+$Neo4j::Driver::Type::Point::VERSION = '0.41';
 
 # may not be supported by Bolt
 
@@ -23,7 +23,7 @@ Neo4j::Driver::Type::Point - Represents a Neo4j spatial point value
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 DESCRIPTION
 
@@ -31,6 +31,9 @@ Represents a spatial point value in Neo4j.
 
 Spatial types are only supported in Neo4j version 3.4 and above.
 
+I<B<Note:> This module documentation will soon be replaced entirely
+by L<Neo4j::Driver::Types> and L<Neo4j::Types::Point>.>
+
 =head1 BUGS
 
 L<Neo4j::Driver::Type::Point> is not yet implemented.
@@ -44,7 +47,9 @@ which L<Neo4j::Bolt> depends on internally. Use HTTP instead.
 
 =over
 
-=item * L<Neo4j::Driver>
+=item * L<Neo4j::Driver::Types>
+
+=item * L<Neo4j::Types::Point>
 
 =item * Equivalent documentation for the official Neo4j drivers:
 L<Point (Java)|https://neo4j.com/docs/api/java-driver/5.2/org.neo4j.driver/org/neo4j/driver/types/Point.html>
