@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Type::Temporal;
 # ABSTRACT: Represents a Neo4j temporal value
-$Neo4j::Driver::Type::Temporal::VERSION = '0.40';
+$Neo4j::Driver::Type::Temporal::VERSION = '0.41';
 
 # may not be supported by Bolt
 
@@ -23,7 +23,7 @@ Neo4j::Driver::Type::Temporal - Represents a Neo4j temporal value
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 DESCRIPTION
 
@@ -31,6 +31,9 @@ Represents a date, time or duration value in Neo4j.
 
 Temporal types are only supported in Neo4j version 3.4 and above.
 
+I<B<Note:> This module documentation will soon be replaced entirely
+by L<Neo4j::Driver::Types>.>
+
 =head1 BUGS
 
 L<Neo4j::Driver::Type::Temporal> is not yet implemented.
@@ -46,7 +49,11 @@ which L<Neo4j::Bolt> depends on internally. Use HTTP instead.
 
 =over
 
-=item * L<Neo4j::Driver>
+=item * L<Neo4j::Driver::Types>
+
+=item * L<Neo4j::Types::DateTime>
+
+=item * L<Neo4j::Types::Duration>
 
 =item * L<"Temporal values" in Neo4j Cypher Manual|https://neo4j.com/docs/cypher-manual/5/syntax/temporal/>
 
